# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/MonsterUI',
                'doc_host': 'https://Isaac-Flath.github.io',
                'git_url': 'https://github.com/Isaac-Flath/MonsterUI',
                'lib_path': 'monsterui'},
  'syms': { 'monsterui.core': { 'monsterui.core.AT': ('core.html#at', 'monsterui/core.py'),
                                'monsterui.core.AT._generate_next_value_': ('core.html#at._generate_next_value_', 'monsterui/core.py'),
                                'monsterui.core.Alert': ('core.html#alert', 'monsterui/core.py'),
                                'monsterui.core.AlertCloseButton': ('core.html#alertclosebutton', 'monsterui/core.py'),
                                'monsterui.core.AlertDescription': ('core.html#alertdescription', 'monsterui/core.py'),
                                'monsterui.core.AlertTitle': ('core.html#alerttitle', 'monsterui/core.py'),
                                'monsterui.core.Article': ('core.html#article', 'monsterui/core.py'),
                                'monsterui.core.ArticleMeta': ('core.html#articlemeta', 'monsterui/core.py'),
                                'monsterui.core.ArticleTitle': ('core.html#articletitle', 'monsterui/core.py'),
                                'monsterui.core.Blockquote': ('core.html#blockquote', 'monsterui/core.py'),
                                'monsterui.core.Button': ('core.html#button', 'monsterui/core.py'),
                                'monsterui.core.ButtonT': ('core.html#buttont', 'monsterui/core.py'),
                                'monsterui.core.ButtonT._generate_next_value_': ( 'core.html#buttont._generate_next_value_',
                                                                                  'monsterui/core.py'),
                                'monsterui.core.Card': ('core.html#card', 'monsterui/core.py'),
                                'monsterui.core.CardBody': ('core.html#cardbody', 'monsterui/core.py'),
                                'monsterui.core.CardContainer': ('core.html#cardcontainer', 'monsterui/core.py'),
                                'monsterui.core.CardFooter': ('core.html#cardfooter', 'monsterui/core.py'),
                                'monsterui.core.CardHeader': ('core.html#cardheader', 'monsterui/core.py'),
                                'monsterui.core.CardT': ('core.html#cardt', 'monsterui/core.py'),
                                'monsterui.core.CardT._generate_next_value_': ( 'core.html#cardt._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.CardTitle': ('core.html#cardtitle', 'monsterui/core.py'),
                                'monsterui.core.CheckboxX': ('core.html#checkboxx', 'monsterui/core.py'),
                                'monsterui.core.CodeSpan': ('core.html#codespan', 'monsterui/core.py'),
                                'monsterui.core.Container': ('core.html#container', 'monsterui/core.py'),
                                'monsterui.core.ContainerT': ('core.html#containert', 'monsterui/core.py'),
                                'monsterui.core.ContainerT._generate_next_value_': ( 'core.html#containert._generate_next_value_',
                                                                                     'monsterui/core.py'),
                                'monsterui.core.DiceBearAvatar': ('core.html#dicebearavatar', 'monsterui/core.py'),
                                'monsterui.core.DivCentered': ('core.html#divcentered', 'monsterui/core.py'),
                                'monsterui.core.DivFullySpaced': ('core.html#divfullyspaced', 'monsterui/core.py'),
                                'monsterui.core.DivHStacked': ('core.html#divhstacked', 'monsterui/core.py'),
                                'monsterui.core.DivLAligned': ('core.html#divlaligned', 'monsterui/core.py'),
                                'monsterui.core.DivRAligned': ('core.html#divraligned', 'monsterui/core.py'),
                                'monsterui.core.DivVStacked': ('core.html#divvstacked', 'monsterui/core.py'),
                                'monsterui.core.Divider': ('core.html#divider', 'monsterui/core.py'),
                                'monsterui.core.DividerLine': ('core.html#dividerline', 'monsterui/core.py'),
                                'monsterui.core.DividerSplit': ('core.html#dividersplit', 'monsterui/core.py'),
                                'monsterui.core.DividerT': ('core.html#dividert', 'monsterui/core.py'),
                                'monsterui.core.DividerT._generate_next_value_': ( 'core.html#dividert._generate_next_value_',
                                                                                   'monsterui/core.py'),
                                'monsterui.core.DropDownNavContainer': ('core.html#dropdownnavcontainer', 'monsterui/core.py'),
                                'monsterui.core.FastHTML': ('core.html#fasthtml', 'monsterui/core.py'),
                                'monsterui.core.Fieldset': ('core.html#fieldset', 'monsterui/core.py'),
                                'monsterui.core.FlexT': ('core.html#flext', 'monsterui/core.py'),
                                'monsterui.core.FlexT._generate_next_value_': ( 'core.html#flext._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.Form': ('core.html#form', 'monsterui/core.py'),
                                'monsterui.core.FormLabel': ('core.html#formlabel', 'monsterui/core.py'),
                                'monsterui.core.GenericLabelInput': ('core.html#genericlabelinput', 'monsterui/core.py'),
                                'monsterui.core.Grid': ('core.html#grid', 'monsterui/core.py'),
                                'monsterui.core.H1': ('core.html#h1', 'monsterui/core.py'),
                                'monsterui.core.H2': ('core.html#h2', 'monsterui/core.py'),
                                'monsterui.core.H3': ('core.html#h3', 'monsterui/core.py'),
                                'monsterui.core.H4': ('core.html#h4', 'monsterui/core.py'),
                                'monsterui.core.Input': ('core.html#input', 'monsterui/core.py'),
                                'monsterui.core.Label': ('core.html#label', 'monsterui/core.py'),
                                'monsterui.core.LabelCheckboxX': ('core.html#labelcheckboxx', 'monsterui/core.py'),
                                'monsterui.core.LabelInput': ('core.html#labelinput', 'monsterui/core.py'),
                                'monsterui.core.LabelRadio': ('core.html#labelradio', 'monsterui/core.py'),
                                'monsterui.core.LabelRange': ('core.html#labelrange', 'monsterui/core.py'),
                                'monsterui.core.LabelSelect': ('core.html#labelselect', 'monsterui/core.py'),
                                'monsterui.core.LabelSwitch': ('core.html#labelswitch', 'monsterui/core.py'),
                                'monsterui.core.LabelT': ('core.html#labelt', 'monsterui/core.py'),
                                'monsterui.core.LabelT._generate_next_value_': ( 'core.html#labelt._generate_next_value_',
                                                                                 'monsterui/core.py'),
                                'monsterui.core.LabelTextArea': ('core.html#labeltextarea', 'monsterui/core.py'),
                                'monsterui.core.LabelUkSelect': ('core.html#labelukselect', 'monsterui/core.py'),
                                'monsterui.core.Legend': ('core.html#legend', 'monsterui/core.py'),
                                'monsterui.core.ListT': ('core.html#listt', 'monsterui/core.py'),
                                'monsterui.core.ListT._generate_next_value_': ( 'core.html#listt._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.Main': ('core.html#main', 'monsterui/core.py'),
                                'monsterui.core.Modal': ('core.html#modal', 'monsterui/core.py'),
                                'monsterui.core.ModalBody': ('core.html#modalbody', 'monsterui/core.py'),
                                'monsterui.core.ModalCloseButton': ('core.html#modalclosebutton', 'monsterui/core.py'),
                                'monsterui.core.ModalContainer': ('core.html#modalcontainer', 'monsterui/core.py'),
                                'monsterui.core.ModalDialog': ('core.html#modaldialog', 'monsterui/core.py'),
                                'monsterui.core.ModalFooter': ('core.html#modalfooter', 'monsterui/core.py'),
                                'monsterui.core.ModalHeader': ('core.html#modalheader', 'monsterui/core.py'),
                                'monsterui.core.ModalTitle': ('core.html#modaltitle', 'monsterui/core.py'),
                                'monsterui.core.NavBarCenter': ('core.html#navbarcenter', 'monsterui/core.py'),
                                'monsterui.core.NavBarContainer': ('core.html#navbarcontainer', 'monsterui/core.py'),
                                'monsterui.core.NavBarLSide': ('core.html#navbarlside', 'monsterui/core.py'),
                                'monsterui.core.NavBarNav': ('core.html#navbarnav', 'monsterui/core.py'),
                                'monsterui.core.NavBarNavContainer': ('core.html#navbarnavcontainer', 'monsterui/core.py'),
                                'monsterui.core.NavBarParentIcon': ('core.html#navbarparenticon', 'monsterui/core.py'),
                                'monsterui.core.NavBarRSide': ('core.html#navbarrside', 'monsterui/core.py'),
                                'monsterui.core.NavBarSubtitle': ('core.html#navbarsubtitle', 'monsterui/core.py'),
                                'monsterui.core.NavCloseLi': ('core.html#navcloseli', 'monsterui/core.py'),
                                'monsterui.core.NavContainer': ('core.html#navcontainer', 'monsterui/core.py'),
                                'monsterui.core.NavDividerLi': ('core.html#navdividerli', 'monsterui/core.py'),
                                'monsterui.core.NavHeaderLi': ('core.html#navheaderli', 'monsterui/core.py'),
                                'monsterui.core.NavParentLi': ('core.html#navparentli', 'monsterui/core.py'),
                                'monsterui.core.NavSubtitle': ('core.html#navsubtitle', 'monsterui/core.py'),
                                'monsterui.core.NavT': ('core.html#navt', 'monsterui/core.py'),
                                'monsterui.core.NavT._generate_next_value_': ('core.html#navt._generate_next_value_', 'monsterui/core.py'),
                                'monsterui.core.Options': ('core.html#options', 'monsterui/core.py'),
                                'monsterui.core.PLarge': ('core.html#plarge', 'monsterui/core.py'),
                                'monsterui.core.PLead': ('core.html#plead', 'monsterui/core.py'),
                                'monsterui.core.PMuted': ('core.html#pmuted', 'monsterui/core.py'),
                                'monsterui.core.PParagraph': ('core.html#pparagraph', 'monsterui/core.py'),
                                'monsterui.core.PSmall': ('core.html#psmall', 'monsterui/core.py'),
                                'monsterui.core.PaddingT': ('core.html#paddingt', 'monsterui/core.py'),
                                'monsterui.core.PaddingT._generate_next_value_': ( 'core.html#paddingt._generate_next_value_',
                                                                                   'monsterui/core.py'),
                                'monsterui.core.Placeholder': ('core.html#placeholder', 'monsterui/core.py'),
                                'monsterui.core.PositionT': ('core.html#positiont', 'monsterui/core.py'),
                                'monsterui.core.PositionT._generate_next_value_': ( 'core.html#positiont._generate_next_value_',
                                                                                    'monsterui/core.py'),
                                'monsterui.core.Progress': ('core.html#progress', 'monsterui/core.py'),
                                'monsterui.core.Radio': ('core.html#radio', 'monsterui/core.py'),
                                'monsterui.core.Range': ('core.html#range', 'monsterui/core.py'),
                                'monsterui.core.Section': ('core.html#section', 'monsterui/core.py'),
                                'monsterui.core.SectionT': ('core.html#sectiont', 'monsterui/core.py'),
                                'monsterui.core.SectionT._generate_next_value_': ( 'core.html#sectiont._generate_next_value_',
                                                                                   'monsterui/core.py'),
                                'monsterui.core.Select': ('core.html#select', 'monsterui/core.py'),
                                'monsterui.core.Switch': ('core.html#switch', 'monsterui/core.py'),
                                'monsterui.core.TabContainer': ('core.html#tabcontainer', 'monsterui/core.py'),
                                'monsterui.core.Table': ('core.html#table', 'monsterui/core.py'),
                                'monsterui.core.TableFromDicts': ('core.html#tablefromdicts', 'monsterui/core.py'),
                                'monsterui.core.TableFromLists': ('core.html#tablefromlists', 'monsterui/core.py'),
                                'monsterui.core.TableT': ('core.html#tablet', 'monsterui/core.py'),
                                'monsterui.core.TableT._generate_next_value_': ( 'core.html#tablet._generate_next_value_',
                                                                                 'monsterui/core.py'),
                                'monsterui.core.Tbody': ('core.html#tbody', 'monsterui/core.py'),
                                'monsterui.core.Td': ('core.html#td', 'monsterui/core.py'),
                                'monsterui.core.TextArea': ('core.html#textarea', 'monsterui/core.py'),
                                'monsterui.core.TextFont': ('core.html#textfont', 'monsterui/core.py'),
                                'monsterui.core.TextFont.__add__': ('core.html#textfont.__add__', 'monsterui/core.py'),
                                'monsterui.core.TextFont.__radd__': ('core.html#textfont.__radd__', 'monsterui/core.py'),
                                'monsterui.core.TextFont.__str__': ('core.html#textfont.__str__', 'monsterui/core.py'),
                                'monsterui.core.TextT': ('core.html#textt', 'monsterui/core.py'),
                                'monsterui.core.TextT._generate_next_value_': ( 'core.html#textt._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.Th': ('core.html#th', 'monsterui/core.py'),
                                'monsterui.core.Thead': ('core.html#thead', 'monsterui/core.py'),
                                'monsterui.core.Theme': ('core.html#theme', 'monsterui/core.py'),
                                'monsterui.core.Theme._create_headers': ('core.html#theme._create_headers', 'monsterui/core.py'),
                                'monsterui.core.Theme._generate_next_value_': ( 'core.html#theme._generate_next_value_',
                                                                                'monsterui/core.py'),
                                'monsterui.core.Theme.headers': ('core.html#theme.headers', 'monsterui/core.py'),
                                'monsterui.core.Theme.local_headers': ('core.html#theme.local_headers', 'monsterui/core.py'),
                                'monsterui.core.Titled': ('core.html#titled', 'monsterui/core.py'),
                                'monsterui.core.Toggle_switch': ('core.html#toggle_switch', 'monsterui/core.py'),
                                'monsterui.core.Tr': ('core.html#tr', 'monsterui/core.py'),
                                'monsterui.core.UkFormSection': ('core.html#ukformsection', 'monsterui/core.py'),
                                'monsterui.core.UkIcon': ('core.html#ukicon', 'monsterui/core.py'),
                                'monsterui.core.UkIconLink': ('core.html#ukiconlink', 'monsterui/core.py'),
                                'monsterui.core.UkList': ('core.html#uklist', 'monsterui/core.py'),
                                'monsterui.core.UkSelect': ('core.html#ukselect', 'monsterui/core.py'),
                                'monsterui.core._TableCell': ('core.html#_tablecell', 'monsterui/core.py'),
                                'monsterui.core._download_resource': ('core.html#_download_resource', 'monsterui/core.py'),
                                'monsterui.core._headers_theme': ('core.html#_headers_theme', 'monsterui/core.py'),
                                'monsterui.core.apply_classes': ('core.html#apply_classes', 'monsterui/core.py'),
                                'monsterui.core.fast_app': ('core.html#fast_app', 'monsterui/core.py'),
                                'monsterui.core.render_md': ('core.html#render_md', 'monsterui/core.py')},
            'monsterui.foundations': { 'monsterui.foundations.VEnum': ('foundation.html#venum', 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__add__': ('foundation.html#venum.__add__', 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__radd__': ( 'foundation.html#venum.__radd__',
                                                                                 'monsterui/foundations.py'),
                                       'monsterui.foundations.VEnum.__str__': ('foundation.html#venum.__str__', 'monsterui/foundations.py'),
                                       'monsterui.foundations.str2ukcls': ('foundation.html#str2ukcls', 'monsterui/foundations.py'),
                                       'monsterui.foundations.stringify': ('foundation.html#stringify', 'monsterui/foundations.py')}}}
